@@ -591,7 +591,7 @@ class FloatSlider(Slider):
 
             # make sure val * precision is within int32 overflow limit for Qt
             val = max([abs(_min), abs(_max)])
-            while abs(self._precision * val) >= 2 ** 32 // 2:
+            while abs(self._precision * val) >= 2**32 // 2:
                 self._precision *= 0.1
         elif step:
             while step < (1 / self._precision):
@@ -688,7 +688,7 @@ class ComboBox(QBaseValueWidget, _protocols.CategoricalWidgetProtocol):
 
         choice_names = [x[0] for x in choices_]
         # remove choices that no longer exist
-        for i in range(self._qwidget.count()):
+        for i in reversed(range(self._qwidget.count())):
             if self._qwidget.itemText(i) not in choice_names:
                 self._qwidget.removeItem(i)
         # update choices
@@ -1201,6 +1201,15 @@ class Table(QBaseWidget, _protocols.TableWidgetProtocol):
 
         self._qwidget.itemChanged.connect(_item_callback)
 
+    # These are only here to implement the ValueWidget interface... but in this one
+    # case, all of the get/set value logic happens in magicgui.widgets.Table
+    # calling Table._mgui_set_cell and Table._mgui_get_cell instead
+    def _mgui_get_value(self):
+        pass
+
+    def _mgui_set_value(self):
+        pass
+
 
 class _ItemDelegate(QtW.QStyledItemDelegate):
     """Displays table widget items with properly formatted numbers."""
